summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmglobalphotonsedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmglobalphotonsedit.h')
-rw-r--r--kpovmodeler/pmglobalphotonsedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmglobalphotonsedit.h b/kpovmodeler/pmglobalphotonsedit.h
index e2ae8f7b..61db154f 100644
--- a/kpovmodeler/pmglobalphotonsedit.h
+++ b/kpovmodeler/pmglobalphotonsedit.h
@@ -38,12 +38,13 @@ class TQCheckBox;
class PMGlobalPhotonsEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMGlobalPhotonsEdit with parent and name
*/
- PMGlobalPhotonsEdit( TQWidget* parent, const char* name = 0 );
+ PMGlobalPhotonsEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,12 +38,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMGlobalPhotonsEdit with parent and name
+ * Creates a PMGlobalPhotonsEdit with tqparent and name
*/